@@ -24,7 +24,7 @@
 
 #include <dcopobject.h>
 #include <kontact/plugin.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 namespace Kontact
 {
@@ -36,7 +36,7 @@ namespace Kontact
  * By default this means simply bringing the main window to the front,
  * but newInstance can be reimplemented.
  */
-class KDE_EXPORT UniqueAppHandler : public DCOPObject
+class TDE_EXPORT UniqueAppHandler : public DCOPObject
 {
   K_DCOP
 
@@ -86,7 +86,7 @@ template <class T> class UniqueAppHandlerFactory : public UniqueAppHandlerFactor
  * Kontact takes over from there.
  *
  */
-class KDE_EXPORT UniqueAppWatcher : public TQObject
+class TDE_EXPORT UniqueAppWatcher : public TQObject
 {
   TQ_OBJECT
   
