@@ -34,7 +34,7 @@ class Basket;
   */
 class ExporterDialog : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
 	ExporterDialog(Basket *basket, TQWidget *parent = 0, const char *name = 0);
