@@ -142,7 +142,7 @@ void KGpgMe::init(gpgme_protocol_t proto)
 
 	err = gpgme_engine_check_version(proto);
 	if(err) {
-		KMessageBox::error(TQT_TQWIDGET(kapp->activeWindow()), TQString("%1: %2")
+		KMessageBox::error(kapp->activeWindow(), TQString("%1: %2")
 			.arg(gpgme_strsource(err)).arg(gpgme_strerror(err)));
 	}
 }
@@ -182,7 +182,7 @@ TQString KGpgMe::checkForUtf8(TQString txt)
 
 TQString KGpgMe::selectKey(TQString previous)
 {
-	KGpgSelKey dlg(TQT_TQWIDGET(kapp->activeWindow()), "", previous, *this);
+	KGpgSelKey dlg(kapp->activeWindow(), "", previous, *this);
 
 	if(dlg.exec())
 		return dlg.key();
@@ -224,13 +224,13 @@ KGpgKeyList KGpgMe::keys(bool privateKeys /* = false */) const
 	}
 
 	if(err) {
-		KMessageBox::error(TQT_TQWIDGET(kapp->activeWindow()), TQString("%1: %2")
+		KMessageBox::error(kapp->activeWindow(), TQString("%1: %2")
 			.arg(gpgme_strsource(err)).arg(gpgme_strerror(err)));
 	}
 	else {
 		result = gpgme_op_keylist_result(m_ctx);
 		if (result->truncated) {
-			KMessageBox::error(TQT_TQWIDGET(kapp->activeWindow()),
+			KMessageBox::error(kapp->activeWindow(),
 				i18n("Key listing unexpectedly truncated."));
 		}
 	}
@@ -266,7 +266,7 @@ bool KGpgMe::encrypt(const TQByteArray& inBuffer, TQ_ULONG length,
 					if(!err) {
 						result = gpgme_op_encrypt_result(m_ctx);
 						if (result->invalid_recipients) {
-							KMessageBox::error(TQT_TQWIDGET(kapp->activeWindow()), TQString("%1: %2")
+							KMessageBox::error(kapp->activeWindow(), TQString("%1: %2")
 								.arg(i18n("That public key is not meant for encryption"))
 								.arg(result->invalid_recipients->fpr));
 						}
@@ -279,7 +279,7 @@ bool KGpgMe::encrypt(const TQByteArray& inBuffer, TQ_ULONG length,
 		}
 	}
 	if(err != GPG_ERR_NO_ERROR && err != GPG_ERR_CANCELED) {
-		KMessageBox::error(TQT_TQWIDGET(kapp->activeWindow()), TQString("%1: %2")
+		KMessageBox::error(kapp->activeWindow(), TQString("%1: %2")
 			.arg(gpgme_strsource(err)).arg(gpgme_strerror(err)));
 	}
 	if(err != GPG_ERR_NO_ERROR)
@@ -309,7 +309,7 @@ bool KGpgMe::decrypt(const TQByteArray& inBuffer, TQByteArray* outBuffer)
 				if(!err) {
 					result = gpgme_op_decrypt_result(m_ctx);
 					if(result->unsupported_algorithm) {
-						KMessageBox::error(TQT_TQWIDGET(kapp->activeWindow()), TQString("%1: %2")
+						KMessageBox::error(kapp->activeWindow(), TQString("%1: %2")
 							.arg(i18n("Unsupported algorithm"))
 							.arg(result->unsupported_algorithm));
 					}
@@ -321,7 +321,7 @@ bool KGpgMe::decrypt(const TQByteArray& inBuffer, TQByteArray* outBuffer)
 		}
 	}
 	if(err != GPG_ERR_NO_ERROR && err != GPG_ERR_CANCELED) {
-		KMessageBox::error(TQT_TQWIDGET(kapp->activeWindow()), TQString("%1: %2")
+		KMessageBox::error(kapp->activeWindow(), TQString("%1: %2")
 			.arg(gpgme_strsource(err)).arg(gpgme_strerror(err)));
 	}
 	if(err != GPG_ERR_NO_ERROR)
