@@ -31,7 +31,6 @@
 #include <kurldrag.h>
 #include <tdemultipledrag.h>
 
-#include <tqsortedlist.h>
 #include <tqimage.h>
 #include <tqpixmap.h>
 #include <tqtimer.h>
@@ -95,9 +94,9 @@ TDEIconCanvas::TDEIconCanvas(TQWidget *parent, const char *name)
     d = new TDEIconCanvasPrivate;
     mpLoader = TDEGlobal::iconLoader();
     mpTimer = new TQTimer(this);
-    connect(mpTimer, TQT_SIGNAL(timeout()), TQT_SLOT(slotLoadFiles()));
-    connect(this, TQT_SIGNAL(currentChanged(TQIconViewItem *)),
-	    TQT_SLOT(slotCurrentChanged(TQIconViewItem *)));
+    connect(mpTimer, TQ_SIGNAL(timeout()), TQ_SLOT(slotLoadFiles()));
+    connect(this, TQ_SIGNAL(currentChanged(TQIconViewItem *)),
+	    TQ_SLOT(slotCurrentChanged(TQIconViewItem *)));
     setAcceptDrops(false);
     setShowToolTips(true);
     setStrictIconSize(false);
