@@ -69,7 +69,7 @@ TQAlphaWidget::TQAlphaWidget( TQWidget* w, WFlags f )
 			   "tqt internal alpha effect widget", f )
 {
 #if 1 //ndef TQ_WS_WIN
-    setEnabled( FALSE );
+    setEnabled( false );
 #endif
 
     pm.setOptimization( TQPixmap::BestOptim );
@@ -103,7 +103,7 @@ void TQAlphaWidget::run( int time )
 	elapsed = 0;
 	checkTime.start();
 
-	showWidget = TRUE;
+	showWidget = true;
 	tqApp->installEventFilter( this );
 
 	widget->setWState( WState_Visible );
@@ -123,7 +123,7 @@ void TQAlphaWidget::run( int time )
 		mixed = back.copy();
 		pm = mixed;
 		show();
-		setEnabled(FALSE);
+		setEnabled(false);
 
 		connect( &anim, TQ_SIGNAL(timeout()), this, TQ_SLOT(render()));
 		anim.start( 1 );
@@ -155,15 +155,15 @@ bool TQAlphaWidget::eventFilter( TQObject* o, TQEvent* e )
 	    break;
 #endif
 		case TQEvent::MouseButtonDblClick:
-			setEnabled(TRUE);
-			showWidget = FALSE;
+			setEnabled(true);
+			showWidget = false;
 			render();
 			break;
 		case TQEvent::KeyPress:
 		{
 			TQKeyEvent *ke = (TQKeyEvent*)e;
 			if ( ke->key() == Key_Escape )
-				showWidget = FALSE;
+				showWidget = false;
 			else
 				duration = 0;
 			render();
@@ -184,7 +184,7 @@ void TQAlphaWidget::closeEvent( TQCloseEvent *e )
 	if ( !q_blend )
 		return;
 
-	showWidget = FALSE;
+	showWidget = false;
 	render();
 
 	TQWidget::closeEvent( e );
@@ -215,7 +215,7 @@ void TQAlphaWidget::render()
 		if ( widget ) {
 			if ( !showWidget ) {
 #ifdef TQ_WS_WIN
-                setEnabled(TRUE);
+                setEnabled(true);
                 setFocus();
 #endif
 		widget->hide();
@@ -251,7 +251,7 @@ void TQAlphaWidget::render()
 			widget->clearWState( WState_ForceHide );
 		alphaBlend();
 		pm = mixed;
-		repaint( FALSE );
+		repaint( false );
 	}
 }
 
@@ -300,7 +300,7 @@ TQRollEffect::TQRollEffect( TQWidget* w, WFlags f, DirFlags orient )
 			   "tqt internal roll effect widget", f ), orientation(orient)
 {
 #if 1 //ndef TQ_WS_WIN
-    setEnabled( FALSE );
+    setEnabled( false );
 #endif
     widget = (TQAccessWidget*) w;
     Q_ASSERT( widget );
@@ -336,7 +336,7 @@ void TQRollEffect::paintEvent( TQPaintEvent* )
 	int y = orientation & DownScroll ? TQMIN(0, currentHeight - totalHeight) : 0;
 
 	bitBlt( this, x, y, &pm,
-			0, 0, pm.width(), pm.height(), CopyROP, TRUE );
+			0, 0, pm.width(), pm.height(), CopyROP, true );
 }
 
 /*
@@ -355,9 +355,9 @@ bool TQRollEffect::eventFilter( TQObject* o, TQEvent* e )
 		case TQEvent::Close:
 			if ( o != widget || done )
 				break;
-			setEnabled(TRUE);
-			showWidget = FALSE;
-			done = TRUE;
+			setEnabled(true);
+			showWidget = false;
+			done = true;
 			scroll();
 			break;
 		case TQEvent::MouseButtonPress:
@@ -368,9 +368,9 @@ bool TQRollEffect::eventFilter( TQObject* o, TQEvent* e )
 		case TQEvent::MouseButtonDblClick:
 			if ( done )
 				break;
-			setEnabled(TRUE);
-			showWidget = FALSE;
-			done = TRUE;
+			setEnabled(true);
+			showWidget = false;
+			done = true;
 			scroll();
 			break;
 		case TQEvent::KeyPress:
@@ -385,8 +385,8 @@ bool TQRollEffect::eventFilter( TQObject* o, TQEvent* e )
 
 
 			if ( ke->key() == Key_Escape )
-				showWidget = FALSE;
-			done = TRUE;
+				showWidget = false;
+			done = true;
 			scroll();
 			break;
 		}
@@ -404,8 +404,8 @@ void TQRollEffect::closeEvent( TQCloseEvent *e )
 	e->accept();
 	if ( done )
 		return;
-	showWidget = FALSE;
-	done = TRUE;
+	showWidget = false;
+	done = true;
 	scroll();
 
 	TQWidget::closeEvent( e );
@@ -442,12 +442,12 @@ void TQRollEffect::run( int time )
 	resize( TQMIN( currentWidth, totalWidth ), TQMIN( currentHeight, totalHeight ) );
 
 	show();
-	setEnabled(FALSE);
+	setEnabled(false);
 
 	tqApp->installEventFilter( this );
 
-	showWidget = TRUE;
-	done = FALSE;
+	showWidget = true;
+	done = false;
 	anim.start( 1 );
 	checkTime.start();
 }
@@ -492,7 +492,7 @@ void TQRollEffect::scroll()
 		if ( orientation & DownScroll || orientation & UpScroll )
 			h = TQMIN( currentHeight, totalHeight );
 
-		setUpdatesEnabled( FALSE );
+		setUpdatesEnabled( false );
 		if ( orientation & UpScroll )
 			y = widget->geometry().y() + TQMAX( 0, totalHeight - currentHeight );
 		if ( orientation & LeftScroll )
@@ -501,8 +501,8 @@ void TQRollEffect::scroll()
 			move( x, y );
 
 		resize( w, h );
-		setUpdatesEnabled( TRUE );
-		repaint( FALSE );
+		setUpdatesEnabled( true );
+		repaint( false );
 	}
 	if ( done ) {
 		anim.stop();
@@ -510,7 +510,7 @@ void TQRollEffect::scroll()
 		if ( widget ) {
 			if ( !showWidget ) {
 #ifdef TQ_WS_WIN
-                setEnabled(TRUE);
+                setEnabled(true);
                 setFocus();
 #endif
 		widget->hide();
